@@ -1,6 +1,12 @@
 import enum
+import functools
+
+class _MyIntFlag(enum.IntFlag):
+    @classmethod
+    def all_flags(cls):
+        flags = functools.reduce(lambda x, y: x | y, cls)
+        return flags
 
-from .helpers import _MyIntFlag
 
 MIN_TERMINAL_BUILD = 2375
 MAX_BARS = 3000
@@ -663,6 +669,7 @@ class ERROR_CODE(enum.IntEnum):
     UNKNOWN_ERROR = -200_003
     INVALID_COMMANDLINE_ARGS = -200_004
 
+
 MQL_TRADE_REQUEST_PROPS = dict(
     action=int,
     magic=int,
